import { EntityState, EntityStore, getEntityType } from '@datorama/akita';
import { Database } from '@angular/fire/database';
export declare class RealTimeService<S extends EntityState<EntityType, string>, EntityType = getEntityType<S>> {
    protected store?: EntityStore<S>;
    protected rtdb: Database;
    private readonly nodePath;
    private readonly pathRef;
    constructor(store?: EntityStore<S>, path?: string, rtdb?: Database);
    get path(): string;
    get idKey(): string;
    /**
     * Function triggered when adding/updating data to the database
     * @note should be overridden
     */
    formatToDatabase(entity: Partial<EntityType>): any;
    /**
     * Function triggered when getting data from database
     * @note should be overridden
     */
    formatFromDatabase(entity: any): EntityType;
    /**
     * @description just sync with node you specified when initialized the service class without updating the store
     */
    syncNode(): import("rxjs").Observable<EntityType>;
    /**
     * @description sync the node with the store. `formatFromDatabase` will be called every time there is data incoming.
     */
    syncNodeWithStore(): import("rxjs").Observable<import("rxfire/database").QueryChange>;
    /**
     * @description adds a store entity to your database.
     * @param entity to add.
     */
    add(entity: Partial<EntityType | EntityType[]>): Promise<any | any[]>;
    /**
     *
     * @param id id of the entity
     * @param entity to update.
     */
    update(id: string, entity: Partial<EntityType> | Partial<EntityType>[]): any;
    update(entity?: Partial<EntityType> | Partial<EntityType>[]): any;
    /**
     *
     * @param id of the entity to remove
     */
    remove(id: string): Error | Promise<void>;
    /**
     * @warn clears the node and every child of the node.
     */
    clearNode(): Promise<void>;
}
